@@ -1,16 +1,14 @@
 from .users import Users
 from .client import Client
 from .apps import Apps
-from decouple import config
 
-KEY = config("STEAM_API_KEY")
 __all__ = ["Steam"]
 
 
 class Steam:
     """Steam API client"""
 
-    def __init__(self, key: str = KEY, headers: dict = {}):
+    def __init__(self, key: str, headers: dict = {}):
         """Constructor for Steam API client"""
         client = Client(key, headers=headers)
         self.__users = Users(client)
